%--------------------------------------------------------------------------
%   Copyright (c) 2020 Princeton Satellite Systems
%   All rights reserved.
%--------------------------------------------------------------------------
% Looking to analyze some data from 2020/02/12

boolLoadData = false;
boolSave     = true;

close all;
if boolLoadData
clear;
fprintf('Loading in the data. \n');
tic;
C2 = readcell('C2--lastdata--00000.txt');
C2 = cell2mat(C2(6:end,1:2));
C3 = readcell('C3--lastdata--00000.txt');
C3 = cell2mat(C3(6:end,1:2));
t  = C2(:,1);
v1 = C2(:,2);
v2 = C3(:,2);
C2 = [];C3 = [];
toc;
end

dt = t(2) - t(1);
fprintf('Decimating. \n');
tic;
[v1D,tD] = DecimateNTimes(v1,t,6);
[v2D,tD] = DecimateNTimes(v2,t,6);
v1D      = v1D - mean(v1D(tD<0));
v2D      = v2D - mean(v2D(tD<0));
dtD      = tD(2)-tD(1);
toc;
fprintf('Integrating. \n');
tic;
phi1 = -MyIntegralInChunks(v1D)*dtD;
phi2 = -MyIntegralInChunks(v2D)*dtD;
toc;

fprintf('Plotting. \n');
tic;
subplot(2,2,1)
plot(tD,v1D,tD,v2D);
xlabel('Time (s)');ylabel('Voltage (V)');
legend('v1','v2');
subplot(2,2,2)
plot(tD,phi1,tD,phi2);
xlabel('Time (s)');ylabel('Diamagnetic signal (V*s)');
legend('phi1','phi2')
subplot(2,2,3)
plot(tD,phi1+phi2,tD,phi2-phi1);
xlabel('Time (s)');ylabel('Diamagnetic signal (V*s)');
legend('Sum','Difference')
subplot(2,2,4)
plot(tD,phi1+phi2,tD,phi2-phi1);
xlabel('Time (s)');ylabel('Diamagnetic signal (V*s)');
legend('Sum','Difference')
set(gca,'xlim',get(gca,'xlim').*[0 0] + [-5e-3 20e-3]);
toc;

if boolSave
  saveas(gcf,'DLsLinearComboAnalysis.pdf');
end


function [x,t] = DecimateNTimes(x,t,N)
for inds = 1:N
  x = (x(1:2:end-1)+x(2:2:end))/2;
  t = (t(1:2:end-1)+t(2:2:end))/2;
end
end

function I = MyIntegral(x)
I     = zeros(size(x));
x     = x(:);
xInds = (1:numel(x))';
I(:)  = sum(x'.*(xInds>=xInds'),2);
end

function I = MyIntegralInChunks(x,N)
if nargin<2
  N = 150; % Observed to be a good size
end
I      = zeros(size(x));
x      = x(:);
ISoFar = 0;
for i = 1:ceil(numel(x)/N)
  startInd           = 1+(i-1)*N;
  endInd             = min(i*N,numel(x));
  I(startInd:endInd) = MyIntegral(x(startInd:endInd)) + ISoFar;
  ISoFar             = I(endInd);
end
end
